#! /bin/sh

####################################
echo "------ LOAD NVP DRIVER ------"
insmod /lib/modules/icx_nvp_emmc.ko
if [ "$?" != 0 ]; then
	echo "insmod(nvp) error"
	exit 1
fi

/sbin/udevsettle

######################################
echo "------ SHOW UPDATE IMAGE ------"

fwfb /root/fwup_bg.rgb
if [ "$?" != 0 ]; then
	echo "fwfb error"
	exit 1
fi

######################################
echo "------ LOAD MG-IP DRIVER ------"

insmod /lib/modules/mg.ko
if [ "$?" != 0 ]; then
	echo "insmod(mg) error"
	/usr/local/bin/fwfb /root/fwup_err.rgb
	exit 1
fi

######################################
echo "------ SET VBUS LIMIT TO 500mA ------"

insmod /lib/modules/icx_power.ko
if [ "$?" != 0 ]; then
	echo "insmod(power) error"
	/usr/local/bin/fwfb /root/fwup_err.rgb
	exit 1
fi

/usr/local/bin/fwpm 500
if [ "$?" != 0 ]; then
	echo "fwpm error"
	/usr/local/bin/fwfb /root/fwup_err.rgb
	exit 1
fi

####################################
echo "------ LOAD KEY DRIVER ------"

insmod /lib/modules/icx_key.ko
# if [ "$?" != 0 ]; then
# 	echo "insmod(icx_key) error"
# 	exit 1
# fi

#############################################
echo "------ MOUNT CONTENTS PARTITION ------"

mount -t vfat -o ro,noatime,shortname=winnt /dev/contents_part /contents
if [ "$?" != 0 ]; then
	echo "**** INVALID FAT ****"
	nvpflag fup 0xFFFFFFFF
	reboot
fi

#####################################
echo "------ GET FIRST SCRIPT ------"

cd /tmp
if [ "$?" != 0 ]; then
	echo "cd(tmp) error"
	/usr/local/bin/fwfb /root/fwup_err.rgb
	exit 1
fi

_UPDATE_FN_=`nvpstr ufn`
if [ "$?" != 0 ]; then
	echo "nvpstr(ufn) error"
	/usr/local/bin/fwfb /root/fwup_err.rgb
	exit 1
fi

if [ ! -f /contents/$_UPDATE_FN_.UPG ]; then
	echo "$_UPDATE_FN_.UPG not found"
	nvpflag fup 0xFFFFFFFF
	reboot
fi

fwpchk -f /contents/$_UPDATE_FN_.UPG -c -0 update.sh
if [ "$?" != 0 ]; then
	echo "**** INVALID FILE ****"
	nvpflag fup 0xFFFFFFFF
	reboot
fi

chmod 755 update.sh
if [ "$?" != 0 ]; then
	echo "chmod(update.sh) error"
	/usr/local/bin/fwfb /root/fwup_err.rgb
	exit 1
fi

######################################
echo "------ EXEC FIRST SCRIPT ------"

/tmp/update.sh
if [ "$?" != 0 ]; then
	exit 1
fi

###############################################
echo "------ UNMOUNT CONTENTS PARTITION ------"

umount /contents
if [ "$?" != 0 ]; then
	echo "umount(contents) error"
	/usr/local/bin/fwfb /root/fwup_err.rgb
	exit 1
fi

###################################
echo "------ RESET FUP FLAG ------"

nvpflag fup 0xFFFFFFFF
if [ "$?" != 0 ]; then
	echo "nvpflag(fup) error"
	/usr/local/bin/fwfb /root/fwup_err.rgb
	exit 1
fi

echo "******************"
echo "**** COMPLETE ****"
echo "******************"

exit 0
